"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const challenge_service_1 = __importDefault(require("../services/challenge.service"));
const http_status_codes_1 = require("http-status-codes");
const step_model_1 = __importDefault(require("../models/step.model"));
const agency_model_1 = __importDefault(require("../models/agency.model"));
const unique_id_generator_1 = require("../utils/unique_id_generator");
class ChallengeController {
    constructor() {
        this.challengeService = new challenge_service_1.default();
        this.step = step_model_1.default;
        this.agency = agency_model_1.default;
        this.getChallenges = async (req, res, next) => {
            try {
                const findAllChallengesData = await this.challengeService.findAllChallenge();
                this.iResponse = { data: findAllChallengesData, message: 'find all' };
                res.status(http_status_codes_1.StatusCodes.OK).json(this.iResponse);
            }
            catch (error) {
                next(error);
            }
        };
        this.getChallengeById = async (req, res, next) => {
            const challengeId = req.params.id;
            try {
                const findOneChallengeData = await this.challengeService.findChallengeById(challengeId);
                this.iResponse = { data: findOneChallengeData, message: 'findOne' };
                res.status(http_status_codes_1.StatusCodes.OK).json(this.iResponse);
            }
            catch (error) {
                next(error);
            }
        };
        this.getChallengeStageById = async (req, res, next) => {
            const challengeId = req.params.id;
            try {
                const findOneChallengeData = await this.challengeService.getChallengeStageById(challengeId);
                this.iResponse = { data: findOneChallengeData, message: 'findOne' };
                res.status(http_status_codes_1.StatusCodes.OK).json(this.iResponse);
            }
            catch (error) {
                next(error);
            }
        };
        this.getChallengeByAgency = async (req, res, next) => {
            const challengeId = req.params.id;
            try {
                const findOneChallengeData = await this.challengeService.findChallengeByAgency(challengeId);
                this.iResponse = { data: findOneChallengeData, message: 'findOne' };
                res.status(http_status_codes_1.StatusCodes.OK).json(this.iResponse);
            }
            catch (error) {
                next(error);
            }
        };
        this.createChallenge = async (req, res, next) => {
            let challengeData = req.body;
            //Generating Challenge id
            let agency = await this.agency.findById(challengeData.agency_id);
            console.log(agency.agencyCode);
            let challenge_id = await (0, unique_id_generator_1.generate_unique_id)('challenge', agency.agencyCode);
            challengeData.challenge_id = challenge_id;
            // console.log(challengeData);
            try {
                let resource_data = req.body.resource_data ? JSON.parse(req.body.resource_data) : '';
                //Updating resources with s3 location
                challengeData.resources = req.files.map(file => {
                    return { media: file.location };
                });
                challengeData.logos = JSON.parse(challengeData.logos);
                challengeData.steps = JSON.parse(challengeData.steps);
                challengeData.slug = challengeData.category.toString().split(' ').join('-');
                const createChallengeData = await this.challengeService.createChallenge(challengeData);
                if (createChallengeData) {
                    (0, unique_id_generator_1.uniqueIdIncrement)('challenge', agency.agencyCode);
                }
                this.iResponse = { data: createChallengeData, message: 'created' };
                res.status(http_status_codes_1.StatusCodes.CREATED).json(this.iResponse);
            }
            catch (error) {
                console.log(error);
                next(error);
            }
        };
        this.updateChallenge = async (req, res, next) => {
            console.log(req);
            const challengeId = req.body.id;
            const challengeData = req.body;
            console.log(challengeData);
            console.log(challengeId);
            //Generating Challenge id
            // let agency:any = await this.agency.findById(challengeData.agency_id);
            // console.log(agency.agencyCode);
            // let challenge_id = await generate_unique_id('challenge', agency.agencyCode);
            // challengeData.challenge_id = challenge_id;
            // console.log(challengeData);
            // let resource_data = JSON.parse(req.body.resource_data);
            //Updating resources with s3 location
            challengeData.resources = "";
            challengeData.logos = JSON.parse(challengeData.logos);
            challengeData.steps = JSON.parse(challengeData.steps);
            challengeData.slug = challengeData.category.toString().split(' ').join('-');
            try {
                const updateChallengeData = await this.challengeService.updateChallenge(challengeId, challengeData);
                this.iResponse = { data: updateChallengeData, message: 'updated' };
                res.status(http_status_codes_1.StatusCodes.OK).json(this.iResponse);
            }
            catch (error) {
                next(error);
            }
        };
        this.deleteChallenge = async (req, res, next) => {
            const challengeId = req.params.id;
            try {
                const deleteChallengeData = await this.challengeService.deleteChallengeData(challengeId);
                this.iResponse = { data: deleteChallengeData, message: 'deleted' };
                res.status(http_status_codes_1.StatusCodes.OK).json(this.iResponse);
            }
            catch (error) {
                next(error);
            }
        };
    }
}
exports.default = ChallengeController;
//# sourceMappingURL=challenge.controller.js.map