"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongoose_1 = require("mongoose");
const paginate_plugin_1 = __importDefault(require("./plugins/paginate.plugin"));
const toJSON_plugin_1 = __importDefault(require("./plugins/toJSON.plugin"));
const userSchema = new mongoose_1.Schema({
    email: {
        type: String,
        required: true,
        unique: true,
        lowercase: true,
    },
    password: {
        type: String,
        required: true,
        trim: true,
        minlength: 8,
        validate(value) {
            if (!value.match(/\d/) || !value.match(/[a-zA-Z]/)) {
                throw new Error('Password must contain at least one letter and one number');
            }
        },
        private: true, // used by the toJSON plugin
    },
    first_name: {
        type: String,
        required: true,
        trim: true,
    },
    last_name: {
        type: String,
        required: true,
        trim: true,
    },
    nationality: {
        type: String,
        trim: true,
    },
    country: {
        type: String,
        trim: true
    },
    age: {
        type: String,
    },
    gender: {
        type: String,
    },
    profession: {
        type: String,
    },
    state: {
        type: String,
    },
    city: {
        type: String,
    },
    address: {
        type: String,
    },
    phone: {
        type: String,
        required: true,
    },
    pincode: {
        type: String,
        default: '',
    },
    role: {
        type: mongoose_1.SchemaTypes.ObjectId,
        ref: 'Role',
        required: true,
    },
    status: {
        type: String,
        enum: ['ACTIVE', 'INACTIVE'],
        default: 'ACTIVE',
        required: true,
    },
}, {
    timestamps: true,
});
userSchema.plugin(toJSON_plugin_1.default);
userSchema.plugin(paginate_plugin_1.default);
const userModel = (0, mongoose_1.model)('User', userSchema);
exports.default = userModel;
//# sourceMappingURL=user.model.js.map