"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = require("express");
const agency_controller_1 = __importDefault(require("../controllers/agency.controller"));
const agency_dto_1 = require("../dtos/agency.dto");
const validation_middleware_1 = __importDefault(require("../middlewares/validation.middleware"));
const auth_middleware_1 = __importDefault(require("../middlewares/auth.middleware"));
class AgencyRoute {
    constructor() {
        this.path = '/agency';
        this.router = (0, express_1.Router)();
        this.agencyController = new agency_controller_1.default();
        this.initializeRoutes();
    }
    initializeRoutes() {
        this.router.get(`${this.path}`, this.agencyController.getAgencies);
        this.router.get(`${this.path}/:id`, auth_middleware_1.default, this.agencyController.getAgencyById);
        this.router.post(`${this.path}`, auth_middleware_1.default, (0, validation_middleware_1.default)(agency_dto_1.CreateAgencyDto, 'body'), this.agencyController.createAgency);
        this.router.put(`${this.path}/:id`, auth_middleware_1.default, (0, validation_middleware_1.default)(agency_dto_1.CreateAgencyDto, 'body', true), this.agencyController.updateAgency);
        this.router.delete(`${this.path}/:id`, auth_middleware_1.default, this.agencyController.deleteAgency);
    }
}
exports.default = AgencyRoute;
//# sourceMappingURL=agency.route.js.map