"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = require("express");
const application_controller_1 = __importDefault(require("../controllers/application.controller"));
const application_dto_1 = require("../dtos/application.dto");
const validation_middleware_1 = __importDefault(require("../middlewares/validation.middleware"));
const auth_middleware_1 = __importDefault(require("../middlewares/auth.middleware"));
const upload_1 = __importDefault(require("../utils/upload"));
class ApplicationRoute {
    constructor() {
        this.path_old = '/applications';
        this.path = '/idea';
        this.router = (0, express_1.Router)();
        this.applicationController = new application_controller_1.default();
        this.initializeRoutes();
    }
    initializeRoutes() {
        this.router.get(`${this.path}`, this.applicationController.getApplications);
        this.router.get('/idea', this.applicationController.getApplications);
        this.router.get(`${this.path}/byUser/:id`, this.applicationController.getApplicationByUser);
        // this.router.get(`${this.path}/:id`, this.applicationController.getApplicationById);
        this.router.get(`${this.path}/challenge/:id`, this.applicationController.getApplicationByChallengeId);
        this.router.post(`${this.path}`, auth_middleware_1.default, (0, validation_middleware_1.default)(application_dto_1.CreateApplicationDto, 'body'), this.applicationController.createApplication);
        this.router.post(`${this.path}/create`, upload_1.default.fields([{ name: 'cv', maxCount: 1 }, { name: 'proof', maxCount: 1 }, { name: 'award', maxCount: 1 }, { name: 'benefit', maxCount: 1 }]), this.applicationController.createIdea);
        this.router.get(`${this.path}/:id`, this.applicationController.getIdeaById);
        this.router.put(`${this.path}/:id`, auth_middleware_1.default, (0, validation_middleware_1.default)(application_dto_1.CreateApplicationDto, 'body', true), this.applicationController.updateApplication);
        this.router.post(`${this.path}/update`, upload_1.default.fields([{ name: 'cv', maxCount: 1 }, { name: 'proof', maxCount: 1 }, { name: 'award', maxCount: 1 }, { name: 'benefit', maxCount: 1 }]), this.applicationController.updateIdea);
        this.router.delete(`${this.path}/:id`, auth_middleware_1.default, this.applicationController.deleteApplication);
    }
}
exports.default = ApplicationRoute;
//# sourceMappingURL=application.route.js.map