"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = require("express");
const challenge_controller_1 = __importDefault(require("../controllers/challenge.controller"));
const auth_middleware_1 = __importDefault(require("../middlewares/auth.middleware"));
const upload_1 = __importDefault(require("../utils/upload"));
class ChallengeRoute {
    constructor() {
        this.path = '/challenges';
        this.router = (0, express_1.Router)();
        this.challengeController = new challenge_controller_1.default();
        this.initializeRoutes();
    }
    initializeRoutes() {
        this.router.get(`${this.path}`, this.challengeController.getChallenges);
        this.router.get(`${this.path}/:id`, this.challengeController.getChallengeById);
        this.router.get(`${this.path}/stage/:id`, this.challengeController.getChallengeStageById);
        this.router.get(`${this.path}/agency/:id`, this.challengeController.getChallengeByAgency);
        this.router.post(`${this.path}/create`, upload_1.default.array('resources', 10), this.challengeController.createChallenge);
        this.router.post(`${this.path}/update`, upload_1.default.array('resources', 10), this.challengeController.updateChallenge);
        this.router.delete(`${this.path}/:id`, auth_middleware_1.default, this.challengeController.deleteChallenge);
    }
}
exports.default = ChallengeRoute;
//# sourceMappingURL=challenge.route.js.map