"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = require("express");
const role_controller_1 = __importDefault(require("../controllers/role.controller"));
const role_dto_1 = require("../dtos/role.dto");
const validation_middleware_1 = __importDefault(require("../middlewares/validation.middleware"));
const auth_middleware_1 = __importDefault(require("../middlewares/auth.middleware"));
class RoleRoute {
    constructor() {
        this.path = '/roles';
        this.router = (0, express_1.Router)();
        this.roleController = new role_controller_1.default();
        this.initializeRoutes();
    }
    initializeRoutes() {
        this.router.get(`${this.path}`, this.roleController.getRoles);
        this.router.get(`${this.path}/:id`, auth_middleware_1.default, this.roleController.getRoleById);
        this.router.post(`${this.path}`, auth_middleware_1.default, (0, validation_middleware_1.default)(role_dto_1.CreateRoleDto, 'body'), this.roleController.createRole);
        this.router.put(`${this.path}/:id`, auth_middleware_1.default, (0, validation_middleware_1.default)(role_dto_1.CreateRoleDto, 'body', true), this.roleController.updateRole);
        this.router.delete(`${this.path}/:id`, auth_middleware_1.default, this.roleController.deleteRole);
    }
}
exports.default = RoleRoute;
//# sourceMappingURL=role.route.js.map