"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = require("express");
const step_controller_1 = __importDefault(require("../controllers/step.controller"));
const step_dto_1 = require("../dtos/step.dto");
const validation_middleware_1 = __importDefault(require("../middlewares/validation.middleware"));
const auth_middleware_1 = __importDefault(require("../middlewares/auth.middleware"));
class StepRoute {
    constructor() {
        this.path = '/steps';
        this.router = (0, express_1.Router)();
        this.stepController = new step_controller_1.default();
        this.initializeRoutes();
    }
    initializeRoutes() {
        this.router.get(`${this.path}`, auth_middleware_1.default, this.stepController.getSteps);
        this.router.get(`${this.path}/:id`, auth_middleware_1.default, this.stepController.getStepById);
        this.router.post(`${this.path}`, auth_middleware_1.default, (0, validation_middleware_1.default)(step_dto_1.CreateStepDto, 'body'), this.stepController.createStep);
        this.router.put(`${this.path}/:id`, auth_middleware_1.default, (0, validation_middleware_1.default)(step_dto_1.CreateStepDto, 'body', true), this.stepController.updateStep);
        this.router.delete(`${this.path}/:id`, auth_middleware_1.default, this.stepController.deleteStep);
    }
}
exports.default = StepRoute;
//# sourceMappingURL=step.route.js.map