"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = require("express");
const user_controller_1 = __importDefault(require("../controllers/user.controller"));
const user_dto_1 = require("../dtos/user.dto");
const validation_middleware_1 = __importDefault(require("../middlewares/validation.middleware"));
const auth_middleware_1 = __importDefault(require("../middlewares/auth.middleware"));
class UsersRoute {
    constructor() {
        this.path = '/users';
        this.router = (0, express_1.Router)();
        this.userController = new user_controller_1.default();
        this.initializeRoutes();
    }
    initializeRoutes() {
        this.router.get(`${this.path}`, auth_middleware_1.default, this.userController.getUsers);
        this.router.get(`${this.path}/:id`, auth_middleware_1.default, this.userController.getUserById);
        this.router.post(`${this.path}`, auth_middleware_1.default, (0, validation_middleware_1.default)(user_dto_1.CreateUserDto, 'body'), this.userController.createUser);
        this.router.put(`${this.path}/:id`, auth_middleware_1.default, (0, validation_middleware_1.default)(user_dto_1.CreateUserDto, 'body', true), this.userController.updateUser);
        this.router.delete(`${this.path}/:id`, auth_middleware_1.default, this.userController.deleteUser);
    }
}
exports.default = UsersRoute;
//# sourceMappingURL=user.route.js.map