"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = require("express");
const video_controller_1 = __importDefault(require("../controllers/video.controller"));
const video_dto_1 = require("../dtos/video.dto");
const validation_middleware_1 = __importDefault(require("../middlewares/validation.middleware"));
const auth_middleware_1 = __importDefault(require("../middlewares/auth.middleware"));
class VideoRoute {
    constructor() {
        this.path = '/videos';
        this.router = (0, express_1.Router)();
        this.videoController = new video_controller_1.default();
        this.initializeRoutes();
    }
    initializeRoutes() {
        this.router.get(`${this.path}`, this.videoController.getVideos);
        this.router.get(`${this.path}/:id`, this.videoController.getVideoById);
        this.router.post(`${this.path}`, auth_middleware_1.default, (0, validation_middleware_1.default)(video_dto_1.CreateVideoDto, 'body'), this.videoController.createVideo);
        this.router.put(`${this.path}/:id`, auth_middleware_1.default, (0, validation_middleware_1.default)(video_dto_1.CreateVideoDto, 'body', true), this.videoController.updateVideo);
        this.router.delete(`${this.path}/:id`, auth_middleware_1.default, this.videoController.deleteVideo);
    }
}
exports.default = VideoRoute;
//# sourceMappingURL=video.route.js.map