"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const HttpException_1 = __importDefault(require("../exceptions/HttpException"));
const agency_model_1 = __importDefault(require("../models/agency.model"));
const util_1 = require("../utils/util");
const user_model_1 = __importDefault(require("../models/user.model"));
const unique_id_generator_1 = require("../utils/unique_id_generator");
class AgencyService {
    constructor() {
        this.agencies = agency_model_1.default;
        this.users = user_model_1.default;
    }
    async findAllAgencies() {
        const agencies = await this.agencies.find();
        return agencies;
    }
    async findAgencyById(agencyId) {
        const findAgency = await this.agencies.findById(agencyId);
        if (!findAgency)
            throw new HttpException_1.default(409, 'Agency Not Found');
        return findAgency;
    }
    async createAgency(agencyData) {
        if ((0, util_1.isEmpty)(agencyData))
            throw new HttpException_1.default(400, 'Agency Data Not Found');
        const findAgency = await this.agencies.findOne({ agencyName: agencyData.agencyName, email: agencyData.email });
        if (findAgency)
            throw new HttpException_1.default(409, `${agencyData.agencyName} already exists`);
        const createAgencyData = await this.agencies.create(agencyData);
        if (createAgencyData) {
            let uniqueId = await (0, unique_id_generator_1.createUniqueId)("challenge", agencyData.agencyCode);
            if (uniqueId == "UID created") {
                console.log("sendgrid key ======>", process.env.SENDGRID_API_KEY);
                // const msg = {
                //   to: createAgencyData.email,
                //   from: 'rohit.singhal@un.org',
                //   subject: 'Agency Registered on GoChange',
                //   html: `<strong>Registered successfully on goChange!!!!</strong> <br> <strong>Login credentials are given below </strong> <br> <strong> Username: </strong> <p> ${createAgencyData.email} </p> <br> <strong> Password: </strong> <p> ${createAgencyData.agencyName}@123 </p>`,
                // };
                // sendMail(msg);
            }
        }
        return createAgencyData;
    }
    async updateAgency(agencyId, agencyData) {
        if ((0, util_1.isEmpty)(agencyData))
            throw new HttpException_1.default(400, 'Agency Data Not Found');
        const updateUserById = await this.users.findByIdAndUpdate(agencyData.userId, agencyData);
        const updateAgencyById = await this.agencies.findByIdAndUpdate(agencyId, agencyData);
        if (!updateAgencyById)
            throw new HttpException_1.default(409, 'Agency Data Not Found');
        return updateAgencyById;
    }
    async deleteAgencyData(agencyId) {
        const deleteAgencyById = await this.agencies.findByIdAndDelete(agencyId);
        if (!deleteAgencyById)
            throw new HttpException_1.default(409, 'Agency Data Not Found');
        return deleteAgencyById;
    }
}
exports.default = AgencyService;
//# sourceMappingURL=agency.service.js.map