"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const HttpException_1 = __importDefault(require("../exceptions/HttpException"));
const application_model_1 = __importDefault(require("../models/application.model"));
const util_1 = require("../utils/util");
class ApplicationService {
    constructor() {
        this.applications = application_model_1.default;
    }
    async findAllApplication() {
        const applications = await this.applications.find();
        return applications;
    }
    async findApplicationById(applicationId) {
        const findApplication = await this.applications.findOne({ _id: applicationId });
        if (!findApplication)
            throw new HttpException_1.default(409, 'Application Not Found');
        return findApplication;
    }
    async findApplicationByUser(userId) {
        const findApplication = await this.applications.find({ user: userId }).populate({ path: 'challenge', populate: {
                path: 'agency_id',
                model: 'Agency'
            } }).sort({ updatedAt: -1 });
        if (!findApplication)
            throw new HttpException_1.default(409, 'Application Not Found');
        return findApplication;
    }
    async createApplication(applicationData) {
        if ((0, util_1.isEmpty)(applicationData))
            throw new HttpException_1.default(400, 'Application Data Not Found');
        const findApplication = await this.applications.findOne({ user: applicationData.user, challenge: applicationData.challenge });
        if (findApplication)
            throw new HttpException_1.default(409, `Application already exists for this challenge`);
        const createApplicationData = await this.applications.create(applicationData);
        return createApplicationData;
    }
    //Create Idea
    async createIdea(ideaData) {
        console.log('application service', ideaData);
        if ((0, util_1.isEmpty)(ideaData))
            throw new HttpException_1.default(400, 'Application Data Not Found');
        const createApplicationData = await this.applications.create({ data: ideaData, challenge: ideaData.challenge_id, user: ideaData.user_id });
        return createApplicationData;
    }
    //Update Idea
    async updateIdea(ideaId, ideaData) {
        if ((0, util_1.isEmpty)(ideaId))
            throw new HttpException_1.default(400, 'Application  Not Found');
        const updateIdeaById = await this.applications.findByIdAndUpdate(ideaId, { $set: { data: ideaData } });
        if (!updateIdeaById)
            throw new HttpException_1.default(409, 'Challenge Data Not Found');
        return updateIdeaById;
    }
    async getIdeaById(ideaid) {
        const findApplication = await this.applications.findOne({ _id: ideaid }).populate('challenge');
        if (!findApplication)
            throw new HttpException_1.default(409, 'Application Not Found');
        return findApplication;
    }
    async getIdeaByChallengeId(challengeid) {
        const findApplication = await this.applications.find({ challenge: challengeid });
        if (!findApplication)
            throw new HttpException_1.default(409, 'Application Not Found');
        return findApplication;
    }
    async updateApplication(applicationId, applicationData) {
        if ((0, util_1.isEmpty)(applicationData))
            throw new HttpException_1.default(400, 'Application Data Not Found');
        const updateApplicationById = await this.applications.findByIdAndUpdate(applicationId, applicationData);
        if (!updateApplicationById)
            throw new HttpException_1.default(409, 'Application Data Not Found');
        return updateApplicationById;
    }
    async deleteApplicationData(applicationId) {
        const deleteApplicationById = await this.applications.findByIdAndDelete(applicationId);
        if (!deleteApplicationById)
            throw new HttpException_1.default(409, 'Application Data Not Found');
        return deleteApplicationById;
    }
}
exports.default = ApplicationService;
//# sourceMappingURL=application.service.js.map