"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const bcrypt_1 = __importDefault(require("bcrypt"));
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const HttpException_1 = __importDefault(require("../exceptions/HttpException"));
const user_model_1 = __importDefault(require("../models/user.model"));
const util_1 = require("../utils/util");
class AuthService {
    constructor() {
        this.users = user_model_1.default;
    }
    async signup(userData) {
        if ((0, util_1.isEmpty)(userData))
            throw new HttpException_1.default(400, "You're not userData");
        const findUser = await this.users.findOne({ email: userData.email });
        if (findUser)
            throw new HttpException_1.default(409, `You're email ${userData.email} already exists`);
        const hashedPassword = await bcrypt_1.default.hash(userData.password, 10);
        const createUserData = await this.users.create(Object.assign(Object.assign({}, userData), { password: hashedPassword }));
        return createUserData;
    }
    async login(userData) {
        try {
            if ((0, util_1.isEmpty)(userData))
                throw new HttpException_1.default(400, "You're not userData");
            let hashPwd = await bcrypt_1.default.hash(userData.password, 10);
            console.log(hashPwd);
            // console.log();
            let findUser = await this.users.aggregate([
                {
                    $match: {
                        email: userData.email,
                    },
                },
                {
                    $lookup: {
                        from: 'roles',
                        localField: 'role',
                        foreignField: '_id',
                        as: 'role',
                    },
                },
                {
                    $unwind: {
                        path: '$role',
                        preserveNullAndEmptyArrays: true,
                    },
                },
                {
                    $lookup: {
                        from: 'agencies',
                        localField: '_id',
                        foreignField: 'userId',
                        as: 'agency',
                    },
                },
                {
                    $unwind: {
                        path: '$agency',
                        preserveNullAndEmptyArrays: true,
                    },
                }
            ]);
            console.log(findUser);
            if (!findUser.length) {
                return {
                    status: 409,
                    error: true,
                    message: `Your email ${userData.email} not found`,
                    data: null
                };
            }
            else {
                findUser = findUser[0];
                console.log(userData.password);
                const isPasswordMatching = await bcrypt_1.default.compare(userData.password, findUser.password);
                console.log(isPasswordMatching);
                if (!isPasswordMatching)
                    return {
                        status: 409,
                        error: true,
                        message: `Your password not matching`,
                        data: null
                    };
                const tokenData = this.createToken(findUser);
                findUser.token = tokenData.token;
                const cookie = this.createCookie(tokenData);
                return {
                    status: 200,
                    error: null,
                    message: "Login Successfull",
                    data: { cookie, findUser }
                };
            }
        }
        catch (error) {
            console.log(error);
        }
    }
    async logout(userData) {
        if ((0, util_1.isEmpty)(userData))
            throw new HttpException_1.default(400, "You're not userData");
        const findUser = await this.users.findOne({ password: userData.password });
        if (!findUser)
            throw new HttpException_1.default(409, "You're not user");
        return findUser;
    }
    createToken(user) {
        const dataStoredInToken = { _id: user._id };
        const secret = process.env.JWT_SECRET;
        const expiresIn = 60 * 60;
        return { expiresIn, token: jsonwebtoken_1.default.sign(dataStoredInToken, secret, { expiresIn }) };
    }
    createCookie(tokenData) {
        return `Authorization=${tokenData.token}; HttpOnly; Max-Age=${tokenData.expiresIn};`;
    }
}
exports.default = AuthService;
//# sourceMappingURL=auth.service.js.map