"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const HttpException_1 = __importDefault(require("../exceptions/HttpException"));
const role_model_1 = __importDefault(require("../models/role.model"));
const util_1 = require("../utils/util");
class RoleService {
    constructor() {
        this.roles = role_model_1.default;
    }
    async findAllRole() {
        const roles = await this.roles.find();
        return roles;
    }
    async findRoleById(roleId) {
        const findRole = await this.roles.findById(roleId);
        if (!findRole)
            throw new HttpException_1.default(409, 'Role Not Found');
        return findRole;
    }
    async createRole(roleData) {
        if ((0, util_1.isEmpty)(roleData))
            throw new HttpException_1.default(400, 'Role Data Not Found');
        const findRole = await this.roles.findOne({ name: roleData.name });
        if (findRole)
            throw new HttpException_1.default(409, `${roleData.name} already exists`);
        const createRoleData = await this.roles.create(roleData);
        return createRoleData;
    }
    async updateRole(roleId, roleData) {
        if ((0, util_1.isEmpty)(roleData))
            throw new HttpException_1.default(400, 'Role Data Not Found');
        const updateRoleById = await this.roles.findByIdAndUpdate(roleId, roleData);
        if (!updateRoleById)
            throw new HttpException_1.default(409, 'Role Data Not Found');
        return updateRoleById;
    }
    async deleteRoleData(roleId) {
        const deleteRoleById = await this.roles.findByIdAndDelete(roleId);
        if (!deleteRoleById)
            throw new HttpException_1.default(409, 'Role Data Not Found');
        return deleteRoleById;
    }
}
exports.default = RoleService;
//# sourceMappingURL=role.service.js.map