"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const HttpException_1 = __importDefault(require("../exceptions/HttpException"));
const step_model_1 = __importDefault(require("../models/step.model"));
const util_1 = require("../utils/util");
class StepService {
    constructor() {
        this.steps = step_model_1.default;
    }
    async findAllStep() {
        const steps = await this.steps.find();
        return steps;
    }
    async findStepById(stepId) {
        const findStep = await this.steps.findById(stepId);
        if (!findStep)
            throw new HttpException_1.default(409, 'Step Not Found');
        return findStep;
    }
    async createStep(stepData) {
        if ((0, util_1.isEmpty)(stepData))
            throw new HttpException_1.default(400, 'Step Data Not Found');
        const findStep = await this.steps.findOne({ name: stepData.name });
        if (findStep)
            throw new HttpException_1.default(409, `${stepData.name} already exists`);
        const createStepData = await this.steps.create(stepData);
        return createStepData;
    }
    async updateStep(stepId, stepData) {
        if ((0, util_1.isEmpty)(stepData))
            throw new HttpException_1.default(400, 'Step Data Not Found');
        const updateStepById = await this.steps.findByIdAndUpdate(stepId, stepData);
        if (!updateStepById)
            throw new HttpException_1.default(409, 'Step Data Not Found');
        return updateStepById;
    }
    async deleteStepData(stepId) {
        const deleteStepById = await this.steps.findByIdAndDelete(stepId);
        if (!deleteStepById)
            throw new HttpException_1.default(409, 'Step Data Not Found');
        return deleteStepById;
    }
}
exports.default = StepService;
//# sourceMappingURL=step.service.js.map