"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const bcrypt_1 = __importDefault(require("bcrypt"));
const HttpException_1 = __importDefault(require("../exceptions/HttpException"));
const user_model_1 = __importDefault(require("../models/user.model"));
const util_1 = require("../utils/util");
class UserService {
    constructor() {
        this.users = user_model_1.default;
    }
    async findAllUser() {
        const users = await this.users.find();
        return users;
    }
    async findUserById(userId) {
        const findUser = await this.users.findById(userId);
        if (!findUser)
            throw new HttpException_1.default(409, "You are not user");
        return findUser;
    }
    async createUser(userData) {
        if ((0, util_1.isEmpty)(userData))
            throw new HttpException_1.default(400, "You're not userData");
        const findUser = await this.users.findOne({ email: userData.email });
        if (findUser)
            throw new HttpException_1.default(409, `Your email ${userData.email} already exists`);
        const hashedPassword = await bcrypt_1.default.hash(userData.password, 10);
        const createUserData = await this.users.create(Object.assign(Object.assign({}, userData), { password: hashedPassword }));
        return createUserData;
    }
    async updateUser(userId, userData) {
        if ((0, util_1.isEmpty)(userData))
            throw new HttpException_1.default(400, "You're not userData");
        const hashedPassword = await bcrypt_1.default.hash(userData.password, 10);
        const updateUserById = await this.users.findByIdAndUpdate(userId, Object.assign(Object.assign({}, userData), { password: hashedPassword }));
        if (!updateUserById)
            throw new HttpException_1.default(409, "You're not user");
        return updateUserById;
    }
    async deleteUserData(userId) {
        const deleteUserById = await this.users.findByIdAndDelete(userId);
        if (!deleteUserById)
            throw new HttpException_1.default(409, "You're not user");
        return deleteUserById;
    }
}
exports.default = UserService;
//# sourceMappingURL=user.service.js.map