"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const HttpException_1 = __importDefault(require("../exceptions/HttpException"));
const video_model_1 = __importDefault(require("../models/video.model"));
const util_1 = require("../utils/util");
class VideoService {
    constructor() {
        this.videos = video_model_1.default;
    }
    async findAllVideo() {
        const videos = await this.videos.find();
        return videos;
    }
    async findVideoById(videoId) {
        const findVideo = await this.videos.findById(videoId);
        if (!findVideo)
            throw new HttpException_1.default(409, 'Video Not Found');
        return findVideo;
    }
    async createVideo(videoData) {
        if ((0, util_1.isEmpty)(videoData))
            throw new HttpException_1.default(400, 'Video Data Not Found');
        const createVideoData = await this.videos.create(videoData);
        return createVideoData;
    }
    async updateVideo(videoId, videoData) {
        if ((0, util_1.isEmpty)(videoData))
            throw new HttpException_1.default(400, 'Video Data Not Found');
        const updateVideoById = await this.videos.findByIdAndUpdate(videoId, videoData);
        if (!updateVideoById)
            throw new HttpException_1.default(409, 'Video Data Not Found');
        return updateVideoById;
    }
    async deleteVideoData(videoId) {
        const deleteVideoById = await this.videos.findByIdAndDelete(videoId);
        if (!deleteVideoById)
            throw new HttpException_1.default(409, 'Video Data Not Found');
        return deleteVideoById;
    }
}
exports.default = VideoService;
//# sourceMappingURL=video.service.js.map